@@ -23,6 +23,7 @@ import apt
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 from gettext import gettext as _
+from I18nHelper import *
 
 class CdromProgress(apt.progress.CdromProgress):
   def __init__(self, datadir, parent, kapp):
@@ -35,7 +36,7 @@ class CdromProgress(apt.progress.CdromProgress):
     self.button_cdrom_close.setEnabled(False)
 
   def close(self):
-    self.dialog_cdrom_progress.hide()
+    self.dialog_cdrom_progress.close()
 
   def update(self, text, step):
     """ update is called regularly so that the gui can be redrawn """
@@ -48,11 +49,11 @@ class CdromProgress(apt.progress.CdromProgress):
     self.kapp.processEvents()
 
   def askCdromName(self):
-    (name, valid) = QInputDialog.getText(self.parent.userinterface, _("CD Name"), _("Please enter a name for the disc"))
+    (name, valid) = QInputDialog.getText(self.parent.userinterface, utf8(_("CD Name")), utf8(_("Please enter a name for the disc")))
     return (valid, unicode(name))
 
   def changeCdrom(self):
-    result = QMessageBox.question(self.parent.userinterface, _("Insert Disk"), _("Please insert a disk in the drive:"), QMessageBox.Ok|QMessageBox.Cancel)
+    result = QMessageBox.question(self.parent.userinterface, utf8(_("Insert Disk")), utf8(_("Please insert a disk in the drive:")), QMessageBox.Ok|QMessageBox.Cancel)
     if result == QMessageBox.Ok:
       print "ok"
       return True
