@@ -59,7 +59,7 @@ class DialogEdit(QDialog):
         comps = c
     self.entry_comps.setText(comps)
 
-    self.entry_comment.setText(source_entry.comment)
+    self.entry_comment.setText(utf8(source_entry.comment))
 
     translate_widget(self)
 
