@@ -255,6 +255,10 @@ class SoftwarePropertiesKDE(SoftwareProperties):
         self.userinterface.vbox_updates_frame.hide()
     self.checkboxTemplates = {}
     for template in self.distro.source_template.children:
+        # Do not show source entries in there
+        if template.type == "deb-src":
+            continue
+
         checkbox = QCheckBox(utf8(template.description), 
                              self.userinterface.vbox_updates_frame)
         checkbox.setObjectName(template.name)
